@@ -6,7 +6,7 @@ import os
 
 def get_fil_price():
     response = requests.request("GET", FIL_PRICE_API)
-    price = response.json()["data"]['average_price_per_GB_per_year']
+    price = response.json()["data"]['historical_average_price_verified']
     price = float(str.split(price)[0]) / 1024 / 1024 / 1024
     return price
 
@@ -21,11 +21,13 @@ def parse_params_to_str(params):
 def get_amount(size, rate):
     fil_price = get_fil_price()
     amount = fil_price * size * 525 / 365 * rate
+    if amount == 0:
+        amount = 0.000002
     return amount
 
 
 def get_contract_abi(abi_name):
-    father_path = os.path.dirname(os.path.dirname(os.path.abspath(__file__))) + "/contract/abi/"
-    with open(father_path + abi_name, 'r') as abi_file:
+    parent_path = os.path.dirname(os.path.dirname(os.path.abspath(__file__))) + "/contract/abi/"
+    with open(parent_path + abi_name, 'r') as abi_file:
         abi_data = json.load(abi_file)
         return json.dumps(abi_data)
